import '../scss/components/button.scss'

/**
 * The standard button to be used everywhere
 * */
export default {
  title: 'Components/Button',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    type: {
      control: 'select',
      options: ['Primary', 'Secondary', 'Tertiary'],
      mapping: {
        Primary: '',
        Secondary: 'rpf-button--secondary',
        Tertiary: 'rpf-button--tertiary',
      },
    },
    size: {
      control: 'select',
      options: ['Large', 'Small'],
      mapping: {
        Large: '',
        Small: 'rpf-button--sm',
      },
    },
    icon: {
      control: 'select',
      options: ['None', 'On Left', 'On Right'],
      mapping: {
        None: 'Button text',
        'On Left': '<span class="rpf-button__icon material-symbols-sharp">sentiment_satisfied</span>Button text',
        'On Right': 'Button text<span class="rpf-button__icon material-symbols-sharp">sentiment_satisfied</span>',
      },
    },
    iconOnly: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    type: 'Primary',
    size: 'Large',
    icon: 'None',
    iconOnly: false,
  },
}

const ButtonTemplate = ({ disabled, icon, iconOnly, size, type }) => {
  const className = ['rpf-button', type, size, iconOnly && 'rpf-button--icon-only'].filter((n) => n).join(' ')
  return `<button class="${className}"${disabled ? ' disabled' : ''}>${
    iconOnly ? '<span class="rpf-button__icon material-symbols-sharp">sentiment_satisfied</span>' : icon
  }</button>`
}

export const Primary = ButtonTemplate.bind({})
Primary.args = {}

export const Secondary = ButtonTemplate.bind({})
Secondary.args = {
  type: 'Secondary',
}

export const Tertiary = ButtonTemplate.bind({})
Tertiary.args = {
  type: 'Tertiary',
}

export const Disabled = ButtonTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const Small = ButtonTemplate.bind({})
Small.args = {
  size: 'Small',
}

export const WithIcon = ButtonTemplate.bind({})
WithIcon.args = {
  icon: 'On Left',
}

export const IconOnly = ButtonTemplate.bind({})
IconOnly.args = {
  iconOnly: true,
}

const LinkTemplate = ({ disabled, icon, size, type }) => {
  const className = ['rpf-button', type, size, disabled ? 'rpf-button--disabled' : ''].filter((n) => n).join(' ')
  return `<a href="#" class="${className}">${icon}</a>`
}

export const Link = LinkTemplate.bind({})
Link.args = {}

export const DisabledLink = LinkTemplate.bind({})
DisabledLink.args = {
  disabled: true,
}
